@@ -242,6 +242,17 @@ class TestDrivers(testtools.TestCase):
         r = requests.get("http://localhost:%d/" % port)
         self.assertEqual(200, r.status_code)
 
+    @testtools.skipUnless(spawn.find_executable("redis-server"),
+                          "redis-server not found")
+    @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
+                          "Gnocchi not found")
+    def test_gnocchi_with_redis_coordinator(self):
+        self.useFixture(gnocchi.GnocchiDriver(coordination_driver="redis"))
+        self.assertEqual("gnocchi://localhost:%d" % 8041,
+                         os.getenv("PIFPAF_URL"))
+        r = requests.get("http://localhost:%d/" % 8041)
+        self.assertEqual(200, r.status_code)
+
     @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
                           "Gnocchi not found")
     def test_gnocchi_with_existing_indexer(self):
@@ -313,25 +324,15 @@ class TestDrivers(testtools.TestCase):
         r = requests.get("http://localhost:%d/" % port)
         self.assertEqual(200, r.status_code)
 
-    @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
-                          "Gnocchi not found")
-    def test_gnocchi_legacy(self):
-        port = gnocchi.GnocchiDriver.DEFAULT_PORT + 10
-        self.useFixture(gnocchi.GnocchiDriver(
-            create_legacy_resource_types=True,
-            port=port,
-            indexer_port=8143))
-        self.assertEqual("gnocchi://localhost:%d" % port,
-                         os.getenv("PIFPAF_URL"))
-        r = requests.get("http://localhost:%d/" % port)
-        self.assertEqual(200, r.status_code)
-
+    @testtools.skipUnless(spawn.find_executable("pg_config"),
+                          "pg_config not found")
     @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
                           "Gnocchi not found")
     @testtools.skipUnless(spawn.find_executable("aodh-api"),
                           "Aodh not found")
-    def test_aodh(self):
-        a = self.useFixture(aodh.AodhDriver())
+    def test_aodh_with_existing_db(self):
+        pg = self.useFixture(postgresql.PostgreSQLDriver(port=12345))
+        a = self.useFixture(aodh.AodhDriver(database_url=pg.url))
         self.assertEqual("aodh://localhost:%d" % a.port,
                          os.getenv("PIFPAF_URL"))
         r = requests.get(os.getenv("PIFPAF_AODH_HTTP_URL"))
@@ -341,14 +342,8 @@ class TestDrivers(testtools.TestCase):
                           "Gnocchi not found")
     @testtools.skipUnless(spawn.find_executable("aodh-api"),
                           "Aodh not found")
-    def test_aodh_gnocchi_legacy(self):
-        a = self.useFixture(aodh.AodhDriver(
-            gnocchi_create_legacy_resource_types=True,
-            port=8100,
-            gnocchi_port=8101,
-            database_port=8102,
-            gnocchi_indexer_port=8201,
-        ))
+    def test_aodh(self):
+        a = self.useFixture(aodh.AodhDriver())
         self.assertEqual("aodh://localhost:%d" % a.port,
                          os.getenv("PIFPAF_URL"))
         r = requests.get(os.getenv("PIFPAF_AODH_HTTP_URL"))
